pub struct SubscriptionsAcknowledgedParams {
pub notifications: SubscriptionFilter,
pub meta: HashMap<String, Value>,
}Expand description
Parameters for the first notification on a subscription stream.
Fields
notifications: SubscriptionFiltermeta: HashMap<String, Value>Trait Implementations
Sourceimpl Clone for SubscriptionsAcknowledgedParams
impl Clone for SubscriptionsAcknowledgedParams
Sourcefn clone(&self) -> SubscriptionsAcknowledgedParams
fn clone(&self) -> SubscriptionsAcknowledgedParams
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<'de> Deserialize<'de> for SubscriptionsAcknowledgedParams
impl<'de> Deserialize<'de> for SubscriptionsAcknowledgedParams
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for SubscriptionsAcknowledgedParams
impl PartialEq for SubscriptionsAcknowledgedParams
Sourcefn eq(&self, other: &SubscriptionsAcknowledgedParams) -> bool
fn eq(&self, other: &SubscriptionsAcknowledgedParams) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for SubscriptionsAcknowledgedParams